declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseHeaders: {
            name: string;
            description: string;
        }[];
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        ttlNote?: undefined;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: ({
            name: string;
            type: string;
            description: string;
            required?: undefined;
        } | {
            name: string;
            type: string;
            description: string;
            required: boolean;
        })[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields?: undefined;
        };
        responseDescription: string;
        responseHeaders: never[];
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            name: string;
            email: string;
            default_ttl_seconds?: undefined;
        };
        ttlNote: string;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                value: import("zod").ZodUnknown;
                contentType: import("zod").ZodString;
                size: import("zod").ZodNumber;
                expiresAt: import("zod").ZodNullable<import("zod").ZodString>;
                firstUsed: import("zod").ZodNullable<import("zod").ZodNumber>;
                lastUsed: import("zod").ZodNullable<import("zod").ZodNumber>;
                count: import("zod").ZodNullable<import("zod").ZodNumber>;
            }, import("zod/v4/core").$strip>;
            prefix: string;
            stripRequired: boolean;
            omit?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseHeaders?: undefined;
        exampleBody?: undefined;
        ttlNote?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                sum: import("zod").ZodNumber;
                count: import("zod").ZodNumber;
                createdAt: import("zod").ZodOptional<import("zod").ZodNumber>;
                lastUsedAt: import("zod").ZodOptional<import("zod").ZodNumber>;
                internal: import("zod").ZodOptional<import("zod").ZodBoolean>;
            }, import("zod/v4/core").$strip>;
            omit: string[];
            prefix?: undefined;
            stripRequired?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseHeaders?: undefined;
        exampleBody?: undefined;
        ttlNote?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                namespaces: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodObject<{
                    sum: import("zod").ZodNumber;
                    count: import("zod").ZodNumber;
                    createdAt: import("zod").ZodOptional<import("zod").ZodNumber>;
                    lastUsedAt: import("zod").ZodOptional<import("zod").ZodNumber>;
                    internal: import("zod").ZodOptional<import("zod").ZodBoolean>;
                }, import("zod/v4/core").$strip>>;
                total: import("zod").ZodNumber;
                limit: import("zod").ZodNumber;
                offset: import("zod").ZodNumber;
                hasMore: import("zod").ZodBoolean;
            }, import("zod/v4/core").$strip>;
            stripRequired: boolean;
            prefix?: undefined;
            omit?: undefined;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        responseHeaders?: undefined;
        exampleBody?: undefined;
        ttlNote?: undefined;
    } | {
        id: string;
        title: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    default_ttl_seconds: import("zod").ZodOptional<import("zod").ZodNumber>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        responseHeaders: never[];
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            default_ttl_seconds: number;
            name?: undefined;
            email?: undefined;
        };
        ttlNote?: undefined;
        responseFields?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map